==============================
Mailing list and Slack channel
==============================

You can join the **lenstronomy** mailing list by signing up on the
`google groups page <https://groups.google.com/forum/#!forum/lenstronomy>`_.

The email list is meant to provide a communication platform between users and developers. You can ask questions,
and suggest new features. New releases will be announced via this mailing list.

We also have a `Slack channel <https://lenstronomers.slack.com>`_ for the community.
Please send us an `email <lenstronomy-dev@googlegroups.com>`_ such that we can add you to the channel.

If you encounter errors or problems with **lenstronomy**, please let us know!
You can open an `issue  <https://github.com/lenstronomy/lenstronomy/issues>`_,
make a post on the `Slack channel <https://lenstronomers.slack.com>`_ or
write an `email <lenstronomy-dev@googlegroups.com>`_ to the lenstronomy developers.

We are also encouraging you to reach out with feature requests, general or specific feedback and questions about use cases.
